==> lxqt-config-1.0.0.tar.xz: lxqt-config-1.0.0/lxqt-config-appearance/translations/lxqt-config-appearance_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>ColorLabel</name>
    <message>
        <location filename="../colorLabel.cpp" line="37"/>
        <source>Click to change color.</source>
        <translation>Valitse vaihtaaksesi väriä.</translation>
    </message>
    <message>
        <location filename="../colorLabel.cpp" line="61"/>
        <source>Select Color</source>
        <translation>Valitse väri</translation>
    </message>
</context>
<context>
    <name>ConfigOtherToolKits</name>
    <message>
        <location filename="../configothertoolkits.cpp" line="170"/>
        <source>GTK themes</source>
        <translation>GTK-teemat</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="171"/>
        <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
        <translation>&lt;p&gt;&apos;%1&apos; on korvattu.&lt;/p&gt;&lt;p&gt;Voit etsiä vanhan asetuksesi kopion sijainnista: &apos;% 2&apos;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="235"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="235"/>
        <source>Error: gsettings cannot be run</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation>Fontti</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation>Käyttöliittymän oletusfontti</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation>Fontin nimi:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation>Tyyli:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="53"/>
        <source>Point size:</source>
        <translation>Pistekoko:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="68"/>
        <source>Normal</source>
        <translation>Normaali</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="73"/>
        <source>Bold</source>
        <translation>Lihavoitu</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="78"/>
        <source>Italic</source>
        <translation>Kursivoitu</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="83"/>
        <source>Bold Italic</source>
        <translation>Lihavoitu sekä kursivoitu</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation>Seuraavat asetukset vaikuttavat vain muutoksen jälkeen käynnistettäviin ohjelmiin</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation>Antialiasoi fontit</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="107"/>
        <source>Font hinting style:</source>
        <translation>Kirjasintyypin vihjeistystyyli:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="118"/>
        <location filename="../fontsconfig.ui" line="183"/>
        <source>None</source>
        <translation>Ei mitään</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="123"/>
        <source>Slight</source>
        <translation>Vähäinen</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="128"/>
        <source>Medium</source>
        <translation>Keskiverto</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="133"/>
        <source>Full</source>
        <translation>Täysi</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="141"/>
        <source>Font hinting</source>
        <translation>Kirjasintyypin vihjeistys</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="148"/>
        <source>Resolution (DPI):</source>
        <translation>Resoluutio (DPI):</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="155"/>
        <source>Autohint</source>
        <translation>Automaattinen vihjeistys</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="172"/>
        <source>Subpixel antialiasing:</source>
        <translation>Osapikselireunanpehmennys:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="188"/>
        <source>RGB</source>
        <translation>RGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="193"/>
        <source>BGR</source>
        <translation>BGR</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="198"/>
        <source>VRGB</source>
        <translation>VRGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="203"/>
        <source>VBGR</source>
        <translation>VBGR</translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>LXQtin ulkoasun hallinta</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation>Kuvaketeema</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="87"/>
        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
        <translation>XDG-kuvaketeemojen KDE-laajennus -&gt; Noudata väriteemaa</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="90"/>
        <source>Colorize icons based on widget style (palette)</source>
        <translation>Väritä kuvakkeet pienoisohjelmatyylin (paletti) mukaan</translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation>LXQt-teema</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="57"/>
        <source>Override user-defined wallpaper</source>
        <translation>Ohita käyttäjän määrittelemä taustakuva</translation>
    </message>
</context>
<context>
    <name>PalettesDialog</name>
    <message>
        <location filename="../palettes.ui" line="14"/>
        <location filename="../palettes.ui" line="20"/>
        <source>Palettes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="33"/>
        <source>Filter...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="43"/>
        <source>&amp;Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>LXQt Appearance Configuration</source>
        <translation>LXQtin ulkoasun hallinta</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Widget Style</source>
        <translation>Pienoisohjelmatyyli</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="82"/>
        <source>Icons Theme</source>
        <translation>Kuvaketeema</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="91"/>
        <source>LXQt Theme</source>
        <translation>LXQt-teema</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="99"/>
        <source>Font</source>
        <translation>Fontti</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="109"/>
        <source>Cursor</source>
        <translation>Kursori</translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../styleconfig.ui" line="33"/>
        <source>Widget Style</source>
        <translation>Pienoisohjelmatyyli</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="63"/>
        <source>Qt Palette</source>
        <translation>Qt-väripaletti</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="77"/>
        <source>Some Qt styles may ignore these colors.</source>
        <translation>Jotkin Qt-tyylit voivat jättää nämä värit huomiotta.</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="102"/>
        <source>Window:</source>
        <translation>Ikkuna:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="112"/>
        <source>View:</source>
        <translation>Näkymä:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="122"/>
        <source>Selection:</source>
        <translation>Valinta:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="132"/>
        <source>Link:</source>
        <translation>Linkki:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="152"/>
        <source>Window Text:</source>
        <translation>Ikkunan teksti:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="162"/>
        <source>View Text:</source>
        <translation>Näkymän teksti:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="172"/>
        <source>Selected Text:</source>
        <translation>Valittu teksti:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="182"/>
        <source>Visited Link:</source>
        <translation>Vierailtu linkki:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="214"/>
        <source>&amp;Save Palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="221"/>
        <source>&amp;Load Palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="241"/>
        <source>&amp;Default Palette</source>
        <translation>&amp;Oletus väripaletti</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="268"/>
        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
        <translation>Aseta GTK-teemat (GTK-asetustiedostot ylikirjoitetaan!)</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="288"/>
        <source>GTK 3 Theme</source>
        <translation>GTK 3 -teema</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="298"/>
        <source>GTK 2 Theme</source>
        <translation>GTK 2 -teema</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="308"/>
        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.

Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
        <translation>Yrittääksesi yhtenäistää teemoitusta, voit valita joko samankaltaisen tyylin/teeman (jos saatavilla) joka listalta tai &apos;gtk2&apos; Qt-tyylin (jos saatavilla)  jäljitelläksesi GTK-teemoja.

Varmista että &apos;xsettingsd&apos; on asennettu helpottaaksesi GTK-ohjelmien teemoitusta lennosta.</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="325"/>
        <source>Toolbar button style:</source>
        <translation>Työkalupalkin painikkeiden tyyli:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="333"/>
        <source>Only display the icon</source>
        <translation>Pelkkä kuvake</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="338"/>
        <source>Only display the text</source>
        <translation>Pelkkä teksti</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="343"/>
        <source>The text appears beside the icon</source>
        <translation>Teksti kuvakkeen vieressä</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="348"/>
        <source>The text appears under the icon</source>
        <translation>Teksti kuvakkeen alapuolella</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="353"/>
        <source>Default</source>
        <translation>Oletus</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="361"/>
        <source>Activate item on single click</source>
        <translation>Aktivoi kohde yhdellä napsautuksella</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="51"/>
        <source>Qt Style</source>
        <translation>Qt-tyyli</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="294"/>
        <location filename="../styleconfig.cpp" line="304"/>
        <source>Save Palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="294"/>
        <source>Palette name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="305"/>
        <source>A palette with the same name exists.
Do you want to replace it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="374"/>
        <source>Remove Palettes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="375"/>
        <source>Do you really want to remove selected palette(s)?
Root palettes will remain intact if existing.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-config_1.3.0.orig.tar.xz: lxqt-config-1.3.0/lxqt-config-appearance/translations/lxqt-config-appearance_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>ColorLabel</name>
    <message>
        <location filename="../colorLabel.cpp" line="37"/>
        <source>Click to change color.</source>
        <translation>Valitse vaihtaaksesi väriä.</translation>
    </message>
    <message>
        <location filename="../colorLabel.cpp" line="61"/>
        <source>Select Color</source>
        <translation>Valitse väri</translation>
    </message>
</context>
<context>
    <name>ConfigOtherToolKits</name>
    <message>
        <location filename="../configothertoolkits.cpp" line="170"/>
        <source>GTK themes</source>
        <translation>GTK-teemat</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="171"/>
        <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
        <translation>&lt;p&gt;&apos;%1&apos; on korvattu.&lt;/p&gt;&lt;p&gt;Voit etsiä vanhan asetuksesi kopion sijainnista: &apos;% 2&apos;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="235"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="235"/>
        <source>Error: gsettings cannot be run</source>
        <translation>Virhe: gsettings-ohjelmaa ei voitu suorittaa</translation>
    </message>
</context>
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation>Fontti</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation>Käyttöliittymän oletusfontti</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation>Fontin nimi:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation>Tyyli:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="53"/>
        <source>Point size:</source>
        <translation>Pistekoko:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="68"/>
        <source>Normal</source>
        <translation>Normaali</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="73"/>
        <source>Bold</source>
        <translation>Lihavoitu</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="78"/>
        <source>Italic</source>
        <translation>Kursivoitu</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="83"/>
        <source>Bold Italic</source>
        <translation>Lihavoitu sekä kursivoitu</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation>Seuraavat asetukset vaikuttavat vain muutoksen jälkeen käynnistettäviin ohjelmiin</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation>Käytä reunanpehmennys fontteja</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="107"/>
        <source>Font hinting style:</source>
        <translation>Kirjasintyypin vihjeistystyyli:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="118"/>
        <location filename="../fontsconfig.ui" line="183"/>
        <source>None</source>
        <translation>Ei mitään</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="123"/>
        <source>Slight</source>
        <translation>Vähäinen</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="128"/>
        <source>Medium</source>
        <translation>Keskivahva</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="133"/>
        <source>Full</source>
        <translation>Täysi</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="141"/>
        <source>Font hinting</source>
        <translation>Kirjasintyypin vihjeistys</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="148"/>
        <source>Resolution (DPI):</source>
        <translation>Resoluutio (DPI):</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="155"/>
        <source>Autohint</source>
        <translation>Automaattinen vihjeistys</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="172"/>
        <source>Subpixel antialiasing:</source>
        <translation>Osapikselireunanpehmennys:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="188"/>
        <source>RGB</source>
        <translation>RGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="193"/>
        <source>BGR</source>
        <translation>BGR</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="198"/>
        <source>VRGB</source>
        <translation>VRGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="203"/>
        <source>VBGR</source>
        <translation>VBGR</translation>
    </message>
</context>
<context>
    <name>GTKConfig</name>
    <message>
        <location filename="../gtkconfig.ui" line="44"/>
        <source>GTK Style</source>
        <translation>GTK-tyyli</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="63"/>
        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
        <translation>Aseta GTK-teemat (GTK-asetustiedostot ylikirjoitetaan!)</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="83"/>
        <source>GTK 3 Theme</source>
        <translation>GTK 3 -teema</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="93"/>
        <source>GTK 2 Theme</source>
        <translation>GTK 2 -teema</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="103"/>
        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.

Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
        <translation>Teemoja yhdenmukaistamiseksi voit valita joko samankaltaisen tyylin/teeman joka listalta (jos saatavilla), tai &apos;gtk2&apos; Qt-tyylin (jos saatavilla) jäljitelläksesi GTK-teemoja.

Varmista että &apos;xsettingsd&apos; on asennettu helpottaaksesi GTK-ohjelmien teemoitusta ilman uudelleenkäynnistystä.</translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>LXQt:n ulkoasun hallinta</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation>Kuvaketeema</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="87"/>
        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
        <translation>XDG-kuvaketeemojen KDE-laajennus -&gt; Noudata väriteemaa</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="90"/>
        <source>Colorize icons based on widget style (palette)</source>
        <translation>Väritä kuvakkeet pienoisohjelmatyylin (paletti) mukaan</translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation>LXQt-teema</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="57"/>
        <source>Use wallpaper provided by theme</source>
        <translation>Käytä teeman tarjoamaa taustakuvaa</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.cpp" line="94"/>
        <source>(User Theme)</source>
        <translation>(Käyttäjäteema)</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.cpp" line="182"/>
        <source>Open theme folder</source>
        <translation>Avaa teemakansio</translation>
    </message>
</context>
<context>
    <name>PalettesDialog</name>
    <message>
        <location filename="../palettes.ui" line="14"/>
        <location filename="../palettes.ui" line="20"/>
        <source>Palettes</source>
        <translation>Väripaletit</translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="33"/>
        <source>Filter...</source>
        <translation>Rajaa...</translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="43"/>
        <source>&amp;Remove</source>
        <translation>&amp;Poista</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>LXQt Appearance Configuration</source>
        <translation>LXQt:n ulkoasun hallinta</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Widget Style</source>
        <translation>Pienoisohjelmatyyli</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <source>Icons Theme</source>
        <translation>Kuvaketeema</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="93"/>
        <source>LXQt Theme</source>
        <translation>LXQt-teema</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="101"/>
        <source>Font</source>
        <translation>Fontti</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="111"/>
        <source>Cursor</source>
        <translation>Kursori</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="118"/>
        <source>GTK Style</source>
        <translation>GTK-tyyli</translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../styleconfig.ui" line="33"/>
        <source>Widget Style</source>
        <translation>Pienoisohjelmatyyli</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="63"/>
        <source>Qt Palette</source>
        <translation>Qt-väripaletti</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="77"/>
        <source>Some Qt styles may ignore these colors.</source>
        <translation>Jotkin Qt-tyylit voivat jättää nämä värit huomiotta.</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="102"/>
        <source>Window:</source>
        <translation>Ikkuna:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="112"/>
        <source>View:</source>
        <translation>Näkymä:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="122"/>
        <source>Selection:</source>
        <translation>Valinta:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="132"/>
        <source>Link:</source>
        <translation>Linkki:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="152"/>
        <source>Window Text:</source>
        <translation>Ikkunan teksti:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="162"/>
        <source>View Text:</source>
        <translation>Näkymän teksti:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="172"/>
        <source>Selected Text:</source>
        <translation>Valittu teksti:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="182"/>
        <source>Visited Link:</source>
        <translation>Vierailtu linkki:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="214"/>
        <source>&amp;Save Palette</source>
        <translation>&amp;Tallenna väripaletti</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="221"/>
        <source>&amp;Load Palette</source>
        <translation>&amp;Lataa väripaletti</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="241"/>
        <source>&amp;Default Palette</source>
        <translation>&amp;Oletusväripaletti</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="256"/>
        <source>Toolbar button style:</source>
        <translation>Työkalupalkin painikkeiden tyyli:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="264"/>
        <source>Only display the icon</source>
        <translation>Pelkkä kuvake</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="269"/>
        <source>Only display the text</source>
        <translation>Pelkkä teksti</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="274"/>
        <source>The text appears beside the icon</source>
        <translation>Teksti kuvakkeen vieressä</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="279"/>
        <source>The text appears under the icon</source>
        <translation>Teksti kuvakkeen alapuolella</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="284"/>
        <source>Default</source>
        <translation>Oletus</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="292"/>
        <source>Activate item on single click</source>
        <translation>Aktivoi kohde yhdellä napsautuksella</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="51"/>
        <source>Qt Style</source>
        <translation>Qt-tyyli</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="245"/>
        <location filename="../styleconfig.cpp" line="255"/>
        <source>Save Palette</source>
        <translation>Tallenna väripaletti</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="245"/>
        <source>Palette name:</source>
        <translation>Väripaletin nimi:</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="256"/>
        <source>A palette with the same name exists.
Do you want to replace it?</source>
        <translation>Saman niminen väripaletti on jo olemassa.
Tahdotko korvata sen?</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="393"/>
        <source>Remove Palettes</source>
        <translation>Poista väripaletteja</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="394"/>
        <source>Do you really want to remove selected palette(s)?
Root palettes will remain intact if existing.</source>
        <translation>Tahdotko varmasti poistaa valitut väripaletit?
Olemassa olevia aloituspaletteja ei muuteta.</translation>
    </message>
</context>
</TS>
